/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * This code was generated by https://code.google.com/p/google-apis-client-generator/
 * (build: 2013-04-09 19:13:20 UTC)
 * on 2013-04-12 at 10:44:24 UTC 
 * Modify at your own risk.
 */

package com.google.api.services.civicinfo.model;

/**
 * Information about a contest that appears on a voter's ballot.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Google Civic Information API. For a detailed
 * explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class Contest extends com.google.api.client.json.GenericJson {

  /**
   * A number specifying the position of this contest on the voter's ballot.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @com.google.api.client.json.JsonString
  private java.lang.Long ballotPlacement;

  /**
   * The candidate choices for this contest.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<Candidate> candidates;

  static {
    // hack to force ProGuard to consider Candidate used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(Candidate.class);
  }

  /**
   * Information about the electoral district that this contest is in.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private ElectoralDistrict district;

  /**
   * A description of any additional eligibility requirements for voting in this contest.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.lang.String electorateSpecifications;

  /**
   * An ID for this object. IDs may change in future requests and should not be cached. Access to
   * this field requires special access that can be requested from the Request more link on the
   * Quotas page.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.lang.String id;

  /**
   * The level of office for this contest. One of: federal, state, county, city, other
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.lang.String level;

  /**
   * The number of candidates that will be elected to office in this contest.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @com.google.api.client.json.JsonString
  private java.lang.Long numberElected;

  /**
   * The number of candidates that a voter may vote for in this contest.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @com.google.api.client.json.JsonString
  private java.lang.Long numberVotingFor;

  /**
   * The name of the office for this contest.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.lang.String office;

  /**
   * If this is a partisan election, the name of the party it is for.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.lang.String primaryParty;

  /**
   * A brief description of the referendum. This field is only populated for contests of type
   * 'Referendum'.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.lang.String referendumSubtitle;

  /**
   * The title of the referendum. (e.g. 'Proposition 42') This field is only populated for contests
   * of type 'Referendum'.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.lang.String referendumTitle;

  /**
   * A link the referendum. This field is only populated for contests of type 'Referendum'.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.lang.String referendumUrl;

  /**
   * A list of sources for this contest. If multiple sources are listed, the data has been
   * aggregated from those sources.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<Source> sources;

  /**
   * "Yes" or "No" depending on whether this a contest being held outside the normal election cycle.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.lang.String special;

  /**
   * The type of contest. Usually this will be 'General', 'Primary', or 'Run-off' for contests with
   * candidates. For referenda this will be 'Referendum'.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.lang.String type;

  /**
   * A number specifying the position of this contest on the voter's ballot.
   * @return value or {@code null} for none
   */
  public java.lang.Long getBallotPlacement() {
    return ballotPlacement;
  }

  /**
   * A number specifying the position of this contest on the voter's ballot.
   * @param ballotPlacement ballotPlacement or {@code null} for none
   */
  public Contest setBallotPlacement(java.lang.Long ballotPlacement) {
    this.ballotPlacement = ballotPlacement;
    return this;
  }

  /**
   * The candidate choices for this contest.
   * @return value or {@code null} for none
   */
  public java.util.List<Candidate> getCandidates() {
    return candidates;
  }

  /**
   * The candidate choices for this contest.
   * @param candidates candidates or {@code null} for none
   */
  public Contest setCandidates(java.util.List<Candidate> candidates) {
    this.candidates = candidates;
    return this;
  }

  /**
   * Information about the electoral district that this contest is in.
   * @return value or {@code null} for none
   */
  public ElectoralDistrict getDistrict() {
    return district;
  }

  /**
   * Information about the electoral district that this contest is in.
   * @param district district or {@code null} for none
   */
  public Contest setDistrict(ElectoralDistrict district) {
    this.district = district;
    return this;
  }

  /**
   * A description of any additional eligibility requirements for voting in this contest.
   * @return value or {@code null} for none
   */
  public java.lang.String getElectorateSpecifications() {
    return electorateSpecifications;
  }

  /**
   * A description of any additional eligibility requirements for voting in this contest.
   * @param electorateSpecifications electorateSpecifications or {@code null} for none
   */
  public Contest setElectorateSpecifications(java.lang.String electorateSpecifications) {
    this.electorateSpecifications = electorateSpecifications;
    return this;
  }

  /**
   * An ID for this object. IDs may change in future requests and should not be cached. Access to
   * this field requires special access that can be requested from the Request more link on the
   * Quotas page.
   * @return value or {@code null} for none
   */
  public java.lang.String getId() {
    return id;
  }

  /**
   * An ID for this object. IDs may change in future requests and should not be cached. Access to
   * this field requires special access that can be requested from the Request more link on the
   * Quotas page.
   * @param id id or {@code null} for none
   */
  public Contest setId(java.lang.String id) {
    this.id = id;
    return this;
  }

  /**
   * The level of office for this contest. One of: federal, state, county, city, other
   * @return value or {@code null} for none
   */
  public java.lang.String getLevel() {
    return level;
  }

  /**
   * The level of office for this contest. One of: federal, state, county, city, other
   * @param level level or {@code null} for none
   */
  public Contest setLevel(java.lang.String level) {
    this.level = level;
    return this;
  }

  /**
   * The number of candidates that will be elected to office in this contest.
   * @return value or {@code null} for none
   */
  public java.lang.Long getNumberElected() {
    return numberElected;
  }

  /**
   * The number of candidates that will be elected to office in this contest.
   * @param numberElected numberElected or {@code null} for none
   */
  public Contest setNumberElected(java.lang.Long numberElected) {
    this.numberElected = numberElected;
    return this;
  }

  /**
   * The number of candidates that a voter may vote for in this contest.
   * @return value or {@code null} for none
   */
  public java.lang.Long getNumberVotingFor() {
    return numberVotingFor;
  }

  /**
   * The number of candidates that a voter may vote for in this contest.
   * @param numberVotingFor numberVotingFor or {@code null} for none
   */
  public Contest setNumberVotingFor(java.lang.Long numberVotingFor) {
    this.numberVotingFor = numberVotingFor;
    return this;
  }

  /**
   * The name of the office for this contest.
   * @return value or {@code null} for none
   */
  public java.lang.String getOffice() {
    return office;
  }

  /**
   * The name of the office for this contest.
   * @param office office or {@code null} for none
   */
  public Contest setOffice(java.lang.String office) {
    this.office = office;
    return this;
  }

  /**
   * If this is a partisan election, the name of the party it is for.
   * @return value or {@code null} for none
   */
  public java.lang.String getPrimaryParty() {
    return primaryParty;
  }

  /**
   * If this is a partisan election, the name of the party it is for.
   * @param primaryParty primaryParty or {@code null} for none
   */
  public Contest setPrimaryParty(java.lang.String primaryParty) {
    this.primaryParty = primaryParty;
    return this;
  }

  /**
   * A brief description of the referendum. This field is only populated for contests of type
   * 'Referendum'.
   * @return value or {@code null} for none
   */
  public java.lang.String getReferendumSubtitle() {
    return referendumSubtitle;
  }

  /**
   * A brief description of the referendum. This field is only populated for contests of type
   * 'Referendum'.
   * @param referendumSubtitle referendumSubtitle or {@code null} for none
   */
  public Contest setReferendumSubtitle(java.lang.String referendumSubtitle) {
    this.referendumSubtitle = referendumSubtitle;
    return this;
  }

  /**
   * The title of the referendum. (e.g. 'Proposition 42') This field is only populated for contests
   * of type 'Referendum'.
   * @return value or {@code null} for none
   */
  public java.lang.String getReferendumTitle() {
    return referendumTitle;
  }

  /**
   * The title of the referendum. (e.g. 'Proposition 42') This field is only populated for contests
   * of type 'Referendum'.
   * @param referendumTitle referendumTitle or {@code null} for none
   */
  public Contest setReferendumTitle(java.lang.String referendumTitle) {
    this.referendumTitle = referendumTitle;
    return this;
  }

  /**
   * A link the referendum. This field is only populated for contests of type 'Referendum'.
   * @return value or {@code null} for none
   */
  public java.lang.String getReferendumUrl() {
    return referendumUrl;
  }

  /**
   * A link the referendum. This field is only populated for contests of type 'Referendum'.
   * @param referendumUrl referendumUrl or {@code null} for none
   */
  public Contest setReferendumUrl(java.lang.String referendumUrl) {
    this.referendumUrl = referendumUrl;
    return this;
  }

  /**
   * A list of sources for this contest. If multiple sources are listed, the data has been
   * aggregated from those sources.
   * @return value or {@code null} for none
   */
  public java.util.List<Source> getSources() {
    return sources;
  }

  /**
   * A list of sources for this contest. If multiple sources are listed, the data has been
   * aggregated from those sources.
   * @param sources sources or {@code null} for none
   */
  public Contest setSources(java.util.List<Source> sources) {
    this.sources = sources;
    return this;
  }

  /**
   * "Yes" or "No" depending on whether this a contest being held outside the normal election cycle.
   * @return value or {@code null} for none
   */
  public java.lang.String getSpecial() {
    return special;
  }

  /**
   * "Yes" or "No" depending on whether this a contest being held outside the normal election cycle.
   * @param special special or {@code null} for none
   */
  public Contest setSpecial(java.lang.String special) {
    this.special = special;
    return this;
  }

  /**
   * The type of contest. Usually this will be 'General', 'Primary', or 'Run-off' for contests with
   * candidates. For referenda this will be 'Referendum'.
   * @return value or {@code null} for none
   */
  public java.lang.String getType() {
    return type;
  }

  /**
   * The type of contest. Usually this will be 'General', 'Primary', or 'Run-off' for contests with
   * candidates. For referenda this will be 'Referendum'.
   * @param type type or {@code null} for none
   */
  public Contest setType(java.lang.String type) {
    this.type = type;
    return this;
  }

  @Override
  public Contest set(String fieldName, Object value) {
    return (Contest) super.set(fieldName, value);
  }

  @Override
  public Contest clone() {
    return (Contest) super.clone();
  }

}
